@@ -89,18 +89,18 @@ try:
 except:
     pass
 
-from PyMca5.PyMcaGui import PyMcaFileDialogs
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 from PyMca5.PyMcaCore import DataObject
 from PyMca5.PyMcaGui.pymca import McaWindow
 from PyMca5.PyMcaCore import StackBase
 from PyMca5.PyMcaCore import McaStackExport
-from PyMca5.PyMcaGui import CloseEventNotifyingWidget
-from PyMca5.PyMcaGui import MaskImageWidget
+from PyMca5.PyMcaGui.misc import CloseEventNotifyingWidget
+from PyMca5.PyMcaGui.plotting import MaskImageWidget
 convertToRowAndColumn = MaskImageWidget.convertToRowAndColumn
 
 from PyMca5.PyMcaGui.pymca import RGBCorrelator
 from PyMca5.PyMcaGui.pymca.RGBCorrelatorWidget import ImageShapeDialog
-from PyMca5.PyMcaGui import IconDict
+from PyMca5.PyMcaGui.plotting.PyMca_Icons import IconDict
 from PyMca5.PyMcaGui.pymca import StackSelector
 from PyMca5 import PyMcaDirs
 from PyMca5.PyMcaIO import ArraySave
@@ -333,7 +333,7 @@ class QStackWidget(StackBase.StackBase,
                                         yScale=yScale)
 
     def _stackSaveToolButtonSignal(self):
-        self._stackSaveMenu.exec_(self.cursor().pos())
+        self._stackSaveMenu.exec(self.cursor().pos())
 
     def _getOutputHDF5Filename(self, nexus=False):
         fileTypes = "HDF5 Files (*.h5)\nHDF5 Files (*.hdf)"
@@ -620,7 +620,7 @@ class QStackWidget(StackBase.StackBase,
             for action in actionList:
                 text = QString(action)
                 menu.addAction(text)
-            a = menu.exec_(qt.QCursor.pos())
+            a = menu.exec(qt.QCursor.pos())
             if a is None:
                 return None
             if qt.safe_str(a.text()).startswith("Replace"):
@@ -812,7 +812,7 @@ class QStackWidget(StackBase.StackBase,
             menu.addAction(text)
             actionList.append(text)
             callableKeys.append(m)
-        a = menu.exec_(qt.QCursor.pos())
+        a = menu.exec(qt.QCursor.pos())
         if a is None:
             return None
         idx = actionList.index(a.text())
@@ -865,7 +865,7 @@ class QStackWidget(StackBase.StackBase,
                 menu.addAction(action)
                 actionList.append((text, pixmap, tip, action))
             menu.hovered.connect(self._actionHovered)
-            a = menu.exec_(qt.QCursor.pos())
+            a = menu.exec(qt.QCursor.pos())
             if a is None:
                 return None
             idx = -1
@@ -1267,6 +1267,35 @@ class QStackWidget(StackBase.StackBase,
             self.stackGraphWidget.setInfoText( \
                     "    X = %d Y = %d Z = %.4g" % (y, x, z))
 
+        if ddict['event'] in ["mouseDoubleClicked"]:
+            if ddict['button'] == "left":
+                if self._stackImageData is None:
+                    return
+                # x and y arrive in scaled coordinates
+                # we need to convert them to row and column
+            if None in [ddict['x'], ddict['y']]:
+                _logger.debug("Signal from outside region %s", ddict)
+                return
+            xScale = self._stack.info.get("xScale", None)
+            yScale = self._stack.info.get("yScale", None)
+            row, column = MaskImageWidget.convertToRowAndColumn(ddict['x'],
+                                      ddict['y'],
+                                      self._stackImageData.shape,
+                                      xScale=xScale,
+                                      yScale=yScale,
+                                      safe=True)
+            ddict['row'] = row
+            ddict['col'] = column
+            selectionMask = numpy.zeros(self._stackImageData.shape,
+                                     numpy.uint8)
+            selectionMask[row, column] = 1
+            dataObject = self.calculateMcaDataObject(normalize=True,
+                                                     mask=selectionMask)
+            self.sendMcaSelection(dataObject,
+                                     key="Selection",
+                                     legend="MCA[%d,%d]" % (row, column),
+                                     action="ADD")
+
     def _mcaWidgetSignal(self, ddict):
         if not self.__ROIConnected:
             return
